## 港股复权行情

接口：hk_daily_adj，可以通过数据工具调试和查看数据。

描述：获取港股复权行情，提供股票股本、市值和成交及换手多个数据指标

限量：单次最大可以提取6000条数据，可循环获取全部，支持分页提取

要求：120积分可以试用查看数据，开通正式权限请参考权限说明文档

注：港股复权逻辑是：价格 * 复权因子 = 复权价格，比如close * adj_factor = 前复权收盘价。复权因子历史数据可能除权等被刷新，请注意动态更新。

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 股票代码（e.g. 00001.HK） |
| trade_date | str | N | 交易日期（YYYYMMDD） |
| start_date | str | N | 开始日期（YYYYMMDD） |
| end_date | str | N | 结束日期（YYYYMMDD） |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 股票代码 |
| trade_date | str | Y | 交易日期 |
| close | float | Y | 收盘价 |
| open | float | Y | 开盘价 |
| high | float | Y | 最高价 |
| low | float | Y | 最低价 |
| pre_close | float | Y | 昨收价 |
| change | float | Y | 涨跌额 |
| pct_change | float | Y | 涨跌幅 |
| vol | None | Y | 成交量 |
| amount | float | Y | 成交额 |
| vwap | float | Y | 平均价 |
| adj_factor | float | Y | 复权因子 |
| turnover_ratio | float | Y | 换手率(基于总股本) |
| free_share | None | Y | 流通股本 |
| total_share | None | Y | 总股本 |
| free_mv | float | Y | 流通市值 |
| total_mv | float | Y | 总市值 |

接口示例

```python
pro = ts.pro_api()

#获取单一股票行情
df = pro.hk_daily_adj(ts_code='00001.HK', start_date='20240101', end_date='20240722')

#获取某一日某个交易所的全部股票
df = pro.hk_daily_adj(trade_date='20240722')
```

数据示例

```python
ts_code trade_date  close pre_close      vol adj_factor turnover_ratio
0    00001.HK   20240722  40.95     40.90  2799284     1.0000           0.07
```